@@ -30,4 +30,18 @@ def startWhatapThread():
     t.setDaemon(True)
     t.start()
 
+
+    def __debug():
+        from whatap.conf.configure import Configure as conf
+        import whatap.util.debug_util as debug_util
+        while True:
+            
+            if conf.debug_stack_enabled:
+                debug_util.printAllStack()
+            time.sleep(10)
+    t = threading.Thread(target=__debug)
+    t.setDaemon(True)
+    t.start()
+
+
 startWhatapThread()
\ No newline at end of file
