@@ -149,17 +149,16 @@ def instrument_mongo_client(module):
             ctx = TraceContextManager.getLocalContext()
             if ctx:
                 if len(args) > 1 and isinstance(args[1], dict):
-                    query = pformat(args[1],compact=True)
+                    query = pformat(args[1], compact=True)
                     
                     ctx.active_sqlhash = query
             callback = fn(*args, **kwargs)
             return callback
-        
         return trace
-    
+
     if hasattr(module, 'version_tuple'):
         (major, minor, buildno) = module.version_tuple
-        if major >= 3 and minor >= 11:
+        if major >= 3:
             if hasattr(module, 'monitoring'):
                 # module.MongoClient.__init__ = wrapper_init(module.MongoClient.__init__)
                 module.monitoring.register(WhatapMongoCmdEventListener())
